@@ -97,7 +97,7 @@ our $grammar = q{
 
     wuri                      : '<' iri '>'                           { $item[2] }
 
-#    uri                       : /(\w+:[^\"\s)\]\>]+)/
+    uri                       : /(\w+:[^\"\s)\]\>]+)/
 
     iri                       : /\w[\w\d\+\-\.]+:\/([^\.\s:;]|\.(?!\s)|:(?!\s)|;(?!\s))+/
 # | '<' ... '>'
